summaryrefslogtreecommitdiffstats
path: root/tdecore/kinstance.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/kinstance.h')
-rw-r--r--tdecore/kinstance.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/tdecore/kinstance.h b/tdecore/kinstance.h
index 24ec92d3f..759581080 100644
--- a/tdecore/kinstance.h
+++ b/tdecore/kinstance.h
@@ -18,7 +18,7 @@
#ifndef _KINSTANCE_H
#define _KINSTANCE_H
-class KStandardDirs;
+class TDEStandardDirs;
class TDEAboutData;
class TDEConfig;
class KIconLoader;
@@ -44,7 +44,7 @@ class TDEGlobalNetworkManager;
*/
class TDECORE_EXPORT TDEInstance
{
- friend class KStandardDirs;
+ friend class TDEStandardDirs;
public:
/**
@@ -80,9 +80,9 @@ class TDECORE_EXPORT TDEInstance
/**
* Returns the application standard dirs object.
* @return The KStandardDirs of the application.
*/
- KStandardDirs *dirs() const;
+ TDEStandardDirs *dirs() const;
/**
* Returns the general config object ("appnamerc").
@@ -163,7 +163,7 @@ protected:
void setConfigName(const TQString &name);
private:
- mutable KStandardDirs *_dirs;
+ mutable TDEStandardDirs *_dirs;
mutable TDEConfig *_config;
mutable KIconLoader *_iconLoader;
@@ -80,9 +80,9 @@ class TDECORE_EXPORT TDEInstance
/**
* Returns the application standard dirs object.
- * @return The KStandardDirs of the application.
+ * @return The TDEStandardDirs of the application.
*/